==> qtjambi-designer-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiDesigner/QDesignerLayoutDecorationExtension_shell.h <==
#ifndef QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H
#define QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/layoutdecoration.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerLayoutDecorationExtension_shell : public QDesignerLayoutDecorationExtension, public QtJambiShellInterface
{
public:
    QDesignerLayoutDecorationExtension_shell();
    ~QDesignerLayoutDecorationExtension_shell() override;

    void adjustIndicator(const QPoint& pos0, int index1) override;
    QPair<int, int> currentCell() const override;
    int currentIndex() const override;
    QDesignerLayoutDecorationExtension::InsertMode currentInsertMode() const override;
    int findItemAt(const QPoint& pos0) const override;
    int findItemAt(int row0, int column1) const override;
    int indexOf(QLayoutItem* item0) const override;
    int indexOf(QWidget* widget0) const override;
    void insertColumn(int column0) override;
    void insertRow(int row0) override;
    void insertWidget(QWidget* widget0, const QPair<int, int>& cell1) override;
    QRect itemInfo(int index0) const override;
    void removeWidget(QWidget* widget0) override;
    void simplify() override;
    QList<QWidget*> widgets(QLayout* layout0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerLayoutDecorationExtension_access : public QDesignerLayoutDecorationExtension
{
    void __qt_adjustIndicator_cref_QPoint_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0, jint index1);
    jobject __qt_currentCell(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentInsertMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_findItemAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0) const;
    jint __qt_findItemAt_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1) const;
    jint __qt_indexOf_QLayoutItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jint __qt_indexOf_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0) const;
    void __qt_insertColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    void __qt_insertRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    void __qt_insertWidget_QWidget_ptr_cref_QPair(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, jobject cell1);
    jobject __qt_itemInfo_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    void __qt_removeWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    void __qt_simplify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_widgets_QLayout_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID layout0) const;
};

#endif // QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H

==> qtjambi-designer-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiDesigner/QDesignerLayoutDecorationExtension_shell.h <==
#ifndef QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H
#define QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/layoutdecoration.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerLayoutDecorationExtension_shell : public QDesignerLayoutDecorationExtension, public QtJambiShellInterface
{
public:
    QDesignerLayoutDecorationExtension_shell();
    ~QDesignerLayoutDecorationExtension_shell() override;

    void adjustIndicator(const QPoint& pos0, int index1) override;
    QPair<int, int> currentCell() const override;
    int currentIndex() const override;
    QDesignerLayoutDecorationExtension::InsertMode currentInsertMode() const override;
    int findItemAt(const QPoint& pos0) const override;
    int findItemAt(int row0, int column1) const override;
    int indexOf(QLayoutItem* item0) const override;
    int indexOf(QWidget* widget0) const override;
    void insertColumn(int column0) override;
    void insertRow(int row0) override;
    void insertWidget(QWidget* widget0, const QPair<int, int>& cell1) override;
    QRect itemInfo(int index0) const override;
    void removeWidget(QWidget* widget0) override;
    void simplify() override;
    QList<QWidget*> widgets(QLayout* layout0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerLayoutDecorationExtension_access : public QDesignerLayoutDecorationExtension
{
    void __qt_adjustIndicator_cref_QPoint_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0, jint index1);
    jobject __qt_currentCell_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentInsertMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_findItemAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0) const;
    jint __qt_findItemAt_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1) const;
    jint __qt_indexOf_QLayoutItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jint __qt_indexOf_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0) const;
    void __qt_insertColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    void __qt_insertRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    void __qt_insertWidget_QWidget_ptr_cref_QPair(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0, jobject cell1);
    jobject __qt_itemInfo_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    void __qt_removeWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    void __qt_simplify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_widgets_QLayout_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID layout0) const;
};

#endif // QDESIGNERLAYOUTDECORATIONEXTENSION_IMPL_SHELL_H
